@@ -1,4 +1,4 @@
-import src.webhook_handler as webhook_handler
+import src.openai_toolbox.webhook_handler as webhook_handler
 import pytest
 from test.webhook_consts import get_webhook
 
